@@ -2,27 +2,28 @@
 
 # groffer - display groff files
 
-# Source file position: <groff-source>/contrib/groffer/man.pl
+# Source file position: <groff-source>/contrib/groffer/perl/man.pl
 # Installed position: <prefix>/lib/groff/groffer/man.pl
 
-# Copyright (C) 2006-2018 Free Software Foundation, Inc.
-# Written by Bernd Warken <groff-bernd.warken-72@web.de>.
+# Copyright (C) 2006, 2009 Free Software Foundation, Inc.
+# Written by Bernd Warken.
 
-# This file is part of 'groffer', which is part of 'groff'.
+# Last update: 5 Jan 2009
 
-# 'groff' is free software; you can redistribute it and/or modify it
+# This file is part of `groffer', which is part of `groff'.
+
+# `groff' is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 2 of the License, or
+# the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
-# 'groff' is distributed in the hope that it will be useful, but
+# `groff' is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # General Public License for more details.
 
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see
-# <http://www.gnu.org/licenses/gpl-2.0.html>.
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 ########################################################################
 
@@ -141,14 +142,14 @@ sub apropos_setup {
 #              $main::Man{EXT}, $tmpdir
 #         out: $main::Manspec
 #
-# Arguments: 1, a hash reference with keys 'name', 'sec', 'ext', where
+# Arguments: 1, a hash refernce with keys 'name', 'sec', 'ext', where
 #               'sec' is a string of one or several section characters
 #
 sub is_man {
   my $n = @_;
   die "is_man(): one argument is needed, you used $n;"
     unless $n == 1;
-  die "is_man(): the argument is not a hash reference '$_[0]';"
+  die "is_man(): the argument is not a hash reference `$_[0]';"
     if ref($_[0]) ne 'HASH';
   die 'is_man(): temporary directory is not set;' unless $main::tmpdir;
   die 'is_man(): man_setup() must be run first;' unless $main::Man{'IS_SETUP'};
@@ -200,18 +201,18 @@ sub is_man {
 # Globals in: $main::Manspec, $main::Man{MANSPEC}, $main::Man{SEC_CHARS},
 #             $main::Man{EXT}, $main::Man{ALL}
 #
-# Arguments: 1, a hash reference with keys 'name', 'sec', 'ext', where
+# Arguments: 1, a hash refernce with keys 'name', 'sec', 'ext', where
 #               'sec' is a string of one or several section characters
 #
 sub man_get {
   my $n = @_;
   die "man_get(): one argument is needed, you used $n;"
     unless $n == 1;
-  die "man_get(): the argument is not a hash reference '$_[0]';"
+  die "man_get(): the argument is not a hash reference `$_[0]';"
     if ref($_[0]) ne 'HASH';
   die "man_get(): is_man() must be run first on the argument;"
     unless $main::Manspec;
-  die "man_get(): wrong hash reference '$_[0]', no 'name' key;"
+  die "man_get(): wrong hash reference `$_[0]', no 'name' key;"
     unless exists $_[0]->{'name'};
 
   my ($name, $sec, $ext, $f, $path);
@@ -334,15 +335,15 @@ sub man_get {
 #           $main::Man{SEC}, $main::Man{ALL}
 #   in/out: $main::Man{ENABLE}
 #
-# The precedence for the variables related to 'man' is that of GNU
-# 'man', i.e.
+# The precedence for the variables related to `man' is that of GNU
+# `man', i.e.
 #
 # $LANG; overridden by
 # $LC_MESSAGES; overridden by
 # $LC_ALL; this has the same precedence as
 # $MANPATH, $MANSEC, $PAGER, $SYSTEM; overridden by
 # $MANOPT; overridden by
-# the groffer command-line options.
+# the groffer command line options.
 #
 # $MANROFFSEQ is ignored because grog determines the preprocessors.
 #
@@ -420,8 +421,7 @@ sub man_setup {
       $main::Man{'LANG2'} =~ s/^(..).*$/$1/;
     }
   }				# if ($lang)
-  # from now on, use only $main::Man{LANG*},
-  # forget about $main::Opt{LANG}, $ENV{LC_*}.
+  # from now on, use only $main::Man{LANG*}, forget about $main::Opt{LANG}, $ENV{LC_*}.
 
   &manpath_add_lang_sys();
 
@@ -462,7 +462,7 @@ sub man_setup {
 # Globals:
 #   in:     $main::Man{SYS}: a list of names of operating systems.
 #           $main::Man{LANG} and $main::Man{LANG2}: each a single name
-#   in/out: @{$main::Man{PATH}}: list of directories which shall have the 'man?'
+#   in/out: @{$main::Man{PATH}}: list of directories which shall have the `man?'
 #           subdirectories.
 #
 sub manpath_add_lang_sys {
@@ -512,7 +512,7 @@ sub manpath_add_lang_sys {
 #
 # Determine basic search path for man pages from $PATH.
 #
-# Return:    '1' if a valid man path was retrieved.
+# Return:    `1' if a valid man path was retrieved.
 # Output:    none
 # Globals:
 #   in:  $PATH
@@ -522,8 +522,7 @@ sub manpath_set_from_path {
   my @path =
     qw( /usr/local /usr /usr/X11R6 /usr/openwin /opt /opt/gnome /opt/kde );
   # get a basic man path from $ENV{PATH}
-  my @path2 = @main::Path;
-  foreach (@path2) {
+  foreach (@main::Path) {
     s#bin/*$##;
     push @path, $_;
   }
@@ -587,7 +586,7 @@ sub special_setup {
 ##########
 # whatis_filename(<filename>)
 #
-# Interpret <filename> as a man page and display its 'whatis'
+# Interpret <filename> as a man page and display its `whatis'
 # information as a fragment written in the groff language.
 #
 # Globals:  in: $main::Opt{'WHATIS'}, $main::Special_Setup, $main::Special_Filespec,
@@ -628,7 +627,7 @@ sub whatis_filename {
     }
   }
 
-  # traditional man style; grep the line containing '.TH' macro, if any
+  # traditional man style; grep the line containing `.TH' macro, if any
   my @catz = &cat_z($_[0]);
   my $res;
   my $test;
@@ -640,7 +639,7 @@ sub whatis_filename {
   }				# foreach (@catz)
 ### whatis_filename()
   if ($test) {			# traditional man style
-    # get the first line after the first '.SH' macro before the next '.SH'
+    # get the first line after the first `.SH' macro before the next `.SH'
     my $test1;
     foreach (@catz) {
       if ($test1) {
@@ -675,7 +674,7 @@ sub whatis_filename {
     return 1;
   }				# if ($test)
 
-  # mdoc style (BSD doc); grep the line containing '.Nd' macro, if any
+  # mdoc style (BSD doc); grep the line containing `.Nd' macro, if any
   foreach (@catz) {
     if (/^[\.']\s*Nd\s/) {		# BSD doc style
       $res =~ s/^(.*)$/$name ($section) \\[em] $1/;
@@ -729,8 +728,3 @@ sub whatis_setup {
 } # whatis_setup ()
 
 1;
-########################################################################
-### Emacs settings
-# Local Variables:
-# mode: CPerl
-# End:
